@@ -1,8 +1,11 @@
 #' Plot a before-after plot with lines joining colour-matched symbols.
 #'
-#' The \code{\link{plot_befafter_colours}}, \code{\link{plot_befafter_colors}} and \code{\link{plot_befafter_shapes}} are for plotting matched data joined by lines. These functions take X and Y variables along with a data column with matching information (e.g. matched subjects or experiments etc.) and plot symbols matched by colour or shape.
-#'
-#'Setting `Boxplot = TRUE` will also plot a box and whiskers plot. 
+#' One of 3 related functions to plot matching data joined by lines. The variable containing information for matching (e.g. matched subjects or experiments etc.) is passed to the `match` argument. 
+#' 1.  \code{\link{plot_befafter_colours}} or \code{\link{plot_befafter_colors}},
+#' 2. \code{\link{plot_befafter_shapes}}  
+#' 3. \code{\link{plot_befafter_box}}
+#' 
+#' In `plot_befafter_colours`/`plot_befafter_colors` and `plot_befafter_shapes` setting `Boxplot = TRUE` will also plot a box and whiskers plot.
 #'
 #' Note that only 25 shapes are available, and there will be errors with \code{\link{plot_befafter_shapes}} when there are fewer than 25 matched observations; instead use \code{\link{plot_befafter_colours}} instead.
 #' 
@@ -13,7 +16,8 @@
 #'
 #' To plot a graph with a single colour along the X axis variable, use the `SingleColour` argument.
 #' 
-#' More complex designs can also be plotted when used with \code{\link[ggplot2]{facet_wrap}} or \code{\link[ggplot2]{facet_grid}}.
+#' The resulting `ggplot2` graph can take additional geometries or other layers. 
+#' 
 #' @param data a data table object, e.g. data.frame or tibble.
 #' @param xcol name of the column containing the categorical variable to be plotted on the X axis.
 #' @param ycol name of the column containing the quantitative Y values.
@@ -58,11 +62,7 @@
 #' Boxplot = TRUE)+
 #' guides(fill = "none", 
 #' colour = "none") #remove guides
-#' #2way ANOVA design with randomised blocks
-#' plot_befafter_colours(data = data_2w_Tdeath, 
-#' xcol = Genotype, ycol = PI, 
-#' match = Experiment) + facet_wrap("Time")
-
+#' 
 plot_befafter_colours <- function(data, xcol, ycol, match, facet, Boxplot = FALSE, symsize = 3, s_alpha = 1, jitter = 0.1, bwid = 0.4, TextXAngle = 0, LogYTrans, LogYBreaks = waiver(), LogYLabels = waiver(), LogYLimits = NULL, facet_scales = "fixed", fontsize = 20, symthick, bthick, lthick, ColPal = c("okabe_ito", "all_grafify", "bright",  "contrast",  "dark",  "fishy",  "kelly",  "light",  "muted",  "pale",  "r4",  "safe",  "vibrant"), ColSeq = TRUE, ColRev = FALSE, SingleColour = "NULL", ...){
   ColPal <- match.arg(ColPal)
   if (missing(bthick)) {bthick = (fontsize)/22}
@@ -70,32 +70,30 @@ plot_befafter_colours <- function(data, xcol, ycol, match, facet, Boxplot = FALS
   if (missing(symthick)) {symthick = fontsize/22}
   if(!Boxplot){
     suppressWarnings(P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
-                                   y = {{ ycol }},
-                                   group = factor({{ match }}))))
+                                                    y = {{ ycol }},
+                                                    group = factor({{ match }}))))
   } else {
     suppressWarnings(P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
-                                   y = {{ ycol }},
-                                   group = factor({{ match }})))+
-      geom_boxplot(aes(group = factor({{ xcol }})),
-                   width = bwid,
-                   outlier.alpha = 0,
-                   size = bthick,
-                   colour = "grey25"))
+                                                    y = {{ ycol }},
+                                                    group = factor({{ match }})))+
+                       geom_boxplot(aes(group = {{ xcol }}),
+                                    width = bwid,
+                                    outlier.alpha = 0,
+                                    linewidth = bthick,
+                                    colour = "grey25"))
   }
   suppressWarnings(P <- P +
-    geom_line(aes(group = factor({{ match }})),
-              colour = "grey35", alpha = 0.8, 
-              position = position_dodge(width = jitter),
-              size = lthick, 
-              ...)+
-    geom_point(size = symsize, 
-               stroke = symthick,
-               alpha = s_alpha, 
-               position = position_dodge(width = jitter),
-               shape = 21,
-               aes(fill = factor({{ match }})), ...)+
-    labs(x = enquo(xcol),
-         fill = enquo(match)))
+                     geom_line(aes(group = factor({{ match }})),
+                               colour = "grey35", alpha = 0.8, 
+                               position = position_dodge(width = jitter),
+                               size = lthick, 
+                               ...)+
+                     geom_point(size = symsize, 
+                                stroke = symthick,
+                                alpha = s_alpha, 
+                                position = position_dodge(width = jitter),
+                                shape = 21,
+                                aes(fill = factor({{ match }})), ...))
   if(!missing(facet)) {
     P <- P + facet_wrap(vars({{ facet }}), 
                         scales = facet_scales, 
@@ -139,7 +137,6 @@ plot_befafter_colours <- function(data, xcol, ycol, match, facet, Boxplot = FALS
     P <- P +
       scale_fill_manual(values = rep(a, 
                                      times = x))+
-      labs(x = enquo(xcol))+
       guides(x = guide_axis(angle = TextXAngle),
              fill = "none")
   } else {
@@ -150,6 +147,8 @@ plot_befafter_colours <- function(data, xcol, ycol, match, facet, Boxplot = FALS
       guides(x = guide_axis(angle = TextXAngle))
   }
   P <- P +
+    labs(x = enquo(xcol),
+         fill = enquo(match))+
     theme_grafify(base_size = fontsize)
   P
 }
