@@ -7,5 +7,9 @@ test_that("XY plot and Cat groups works", {
   expect_equal(g1$theme$text$size, 20)
   expect_equal(g1$labels$x[1], "disp")
   expect_equal(g1$labels$y[1], "hp")
-  expect_equal(g1$guides$x$angle, 45)
+  if (utils::packageVersion("ggplot2") <= "3.4.2") {
+    expect_equal(g1$guides$x$angle, 45)
+  } else {
+    expect_equal(g1$guides$x$angle, 45)
+  }
 })
